# DOX

Paper: **DOX - Document Store Exploration through Keywords** 

DOX (**D**ocument st**O**re e**X**ploration) is a framework for keyword exploration over Document Stores.

## Source code

- All code can be found at the `src` folder.
- Folders outside are used for bootstrap and runtime configurations.

## Demo

- An online demo of the framework is ready to run in [Google Colaboratory](https://colab.research.google.com/drive/1AEvc66EhOnV24NEcl_oBRSqDp0kiVIul). This demo uses an instance of a MongoDB database hosted at [MongoDB Atlas](https://www.mongodb.com/atlas/database).

## Datasets

- All datasets used throughout our experiments can be found [here](https://drive.google.com/drive/folders/1HZtAVXN180O5v2UK6u2c89e2V_jhVSGZ?usp=share_link).
